<?php
/**
 * Plugin Name:     FlavorCloud Shipping For Woocommerce
 * Plugin URI: https://qwebmaster.com/flavor-cloud-shipping-for-woocommerce/
 * Description:    FlavorCloud Shipping For Woocommerce is a plugin that provides live shipping rates using the FlavorCloud API. It offers seamless WooCommerce integration, accurate rate calculations, and compatibility with metric and imperial units.
 * Version:         1.1.9
 * Tested up to:    6.2.2
 * WC requires at least: 3.0
 * WC tested up to: 7.8.0
 * Author:          Qwebmaster
 * Author URI: https://qwebmaster.com
 * 
 * Copyright: © 2023 Qwebmaster
 * License:         GNU General Public License v3.0
 * License URI:     http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain:     woocommerce
 *
 * @package         main
 */

    /*
    V1.1.3
    * Added Country of origin field, this needs to be selected for each product. 
    */

    /*
    V1.1.4
    * Added Options to disable each shipping method.
    */

    /*
    V1.1.6
    * Paypal Checkout issue with WooCommerce PayPal Payments
    * Performance enhamcements
    */

    /*
    V1.1.7
    * Added a new option to disable products from the FlavorCloud Shipping Quote (Gifts Packing etc)
    * Other enhancements<
    */

    /*
    V1.1.8
    * Enhanced compatibility with WooCommerce's metric and imperial unit system
    * Upgraded 3D/4D BoxPacker module
    * Rectified PHP log notices
    * Implemented various minor enhancements
    */

    /*
    V1.1.9
    * Fixed broken settings link to FlavorCloud
    * Added custom boxes to the settings page
    * Added Option to reverse shipping method on the cart and checkout pages.
    * Other minor improvements
    */


// Define Base Plugin Dir 
define( 'FCSFW_PLUGIN_DIR_PATH', plugin_dir_path( __FILE__ ) );
define( 'FCSFW_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );

// Include necessary files
function include_wc_fcsfw_plugin_files() {
    /** FlavorCloud_Shipping_For_Woocommerce Debug Functions */
    require FCSFW_PLUGIN_DIR_PATH . 'includes/fcsfw-debug.php';

    /** FlavorCloud_Shipping_For_Woocommerce Main WooCommerce Functions */
    require FCSFW_PLUGIN_DIR_PATH . 'includes/fcsfw-woocommerce.php';

    /** FlavorCloud_Shipping_For_Woocommerce Main API Functions */
    require FCSFW_PLUGIN_DIR_PATH . 'includes/flavorcloud/api-main.php';

    /** FlavorCloud_Shipping_For_Woocommerce admin */
    require FCSFW_PLUGIN_DIR_PATH . 'includes/flavorcloud-shipping-admin.php';

    // Uncomment the following lines to print the settings arrays
    // fcsfw_print_array(FlavorCloud_API_Get_Settings('ShipFromAddress'));
    // fcsfw_print_array(FlavorCloud_API_Get_Settings('API'));
}
// Run the custom function on woocommerce_init action
add_action('woocommerce_init', 'include_wc_fcsfw_plugin_files');

/**
 * Add Flavor Cloud Shipping Method
 */
add_filter( 'woocommerce_shipping_methods', 'register_flavorcloud_method' );
function register_flavorcloud_method( $methods ) {
    // Only Run On the Checkout page 
    //if ( is_cart() || is_checkout() ) {
    if ( is_cart() || is_checkout() || is_admin() || wp_doing_ajax() ) {
    require_once("includes/wc-flavorcloud-shipping-method.php");
	// $method contains available shipping methods
	$methods[ 'flavor-cloud' ] = 'WC_Shipping_FlavorCloud';
    }
	return $methods;
}

add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), 'add_settings_link_to_flavorcloud_plugin' );
function add_settings_link_to_flavorcloud_plugin( $links ) {
    $settings_url = admin_url( 'admin.php?page=wc-settings&tab=shipping&section=flavor_cloud_settings' );
    $settings_link = '<a href="' . esc_url( $settings_url ) . '">' . __( 'Settings', 'flavor-cloud-shipping-for-woocommerce' ) . '</a>';
    array_unshift( $links, $settings_link );
    return $links;
}

/**
*  Event Logger Woocommerce -> Status -> Log
*
* @since 1.0.2
*/
function fcsfw_logger($data){
  //$options = get_option( 'wsrr_option' );
  //if ($options['wsrr_debug'] == 1 ) {
    $logger = wc_get_logger();
    $logger->debug( $data, array( 'source' => 'woocommerce-flavorcloud-shipping' ) );
 // }
}

